pywr.recorders.MeanParameterRecorder
====================================

.. currentmodule:: pywr.recorders

.. autoclass:: MeanParameterRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MeanParameterRecorder.after
      ~MeanParameterRecorder.aggregated_value
      ~MeanParameterRecorder.before
      ~MeanParameterRecorder.finish
      ~MeanParameterRecorder.load
      ~MeanParameterRecorder.register
      ~MeanParameterRecorder.reset
      ~MeanParameterRecorder.setup
      ~MeanParameterRecorder.unregister
      ~MeanParameterRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MeanParameterRecorder.agg_func
      ~MeanParameterRecorder.children
      ~MeanParameterRecorder.comment
      ~MeanParameterRecorder.epsilon
      ~MeanParameterRecorder.factor
      ~MeanParameterRecorder.ignore_nan
      ~MeanParameterRecorder.is_constraint
      ~MeanParameterRecorder.is_objective
      ~MeanParameterRecorder.model
      ~MeanParameterRecorder.name
      ~MeanParameterRecorder.parameter
      ~MeanParameterRecorder.parents
   
   